@@ -6,8 +6,8 @@ import os
 import threading
 import time
 import copy
-import image
-import im_functions
+from simpledit import image
+from simpledit import im_functions
 
 
 class Ui_MainWindow(object):
